/* Copyright (c) 2016 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */
 
#include "buttons.h"
#include "sdk_errors.h"
#include "bsp.h"
#include "app_timer.h"
#include "nfc_pair_module.h"
#include "ble_module.h"
#include "peer_manager.h"

#define NRF_LOG_MODULE_NAME "BUTTONS"
#include "nrf_log.h"
#include "nrf_log_ctrl.h"

#define APP_TIMER_OP_QUEUE_SIZE 4               /**< Size of timer operation queues. */                               
#define APP_TIMER_PRESCALER     0               /**< Value of the RTC1 PRESCALER register. */

#define APP_BTN_EVT_DISCONNECT  BSP_EVENT_KEY_2 /**< Event used to terminate connection with BLE peripheral device. */
#define APP_BTN_EVT_PAIR        BSP_EVENT_KEY_3 /**< Event used to initiate NFC pairing with BLE peripheral device. */
#define APP_BTN_RELEASE_BONDS   BSP_EVENT_KEY_0 /**< Deletes all bonds. */

/**@brief Function for handling events from the BSP module.
 *
 * @param[in]   event   Event generated by button press.
 */
static void bsp_event_handler(bsp_event_t event)
{
    ret_code_t err_code;

    switch (event)
    {
        case APP_BTN_EVT_DISCONNECT:
            if(ble_is_connected())
            {
                NRF_LOG_INFO("Terminating BLE connection...\r\n");
                nfc_oob_pairing_tag_invalidate();                
                ble_disconnect();
            }
            else
            {
                NRF_LOG_INFO("Releasing bondings...\r\n");
                err_code = pm_peers_delete();
                APP_ERROR_CHECK(err_code);
            }
            break;
        
        case APP_BTN_EVT_PAIR:
            NRF_LOG_INFO("Initiate NFC pairing...\r\n");
            nfc_pair_start();
            break;
        
        default:
            break;
    }
}

void buttons_init(void)
{
    ret_code_t err_code;

    // Application timer initialization
    APP_TIMER_INIT(APP_TIMER_PRESCALER, APP_TIMER_OP_QUEUE_SIZE, false);
 
    // Initialize buttons and add bsp buttons task to the application timer
    err_code = bsp_init(BSP_INIT_BUTTONS | BSP_INIT_LED, APP_TIMER_TICKS(100, APP_TIMER_PRESCALER), bsp_event_handler);
    APP_ERROR_CHECK(err_code);   
}
